@@ -20,8 +20,8 @@ class TimeRangeModel(models.Model):
 
 
 class UserTrackModel(models.Model):
-    created_by = CurrentUserField(on_delete=models.PROTECT, verbose_name=_('created_by'))
-    updated_by = CurrentUserField(on_delete=models.PROTECT, on_update=True, verbose_name=_('updated_by'))
+    created_by = CurrentUserField(on_delete=models.PROTECT, related_name='+', verbose_name=_('created_by'))
+    updated_by = CurrentUserField(on_delete=models.PROTECT, on_update=True, related_name='+', verbose_name=_('updated_by'))
 
     class Meta:
         abstract = True
